summaryrefslogtreecommitdiffstats
path: root/kdirstat/kcleanupcollection.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-04 21:28:42 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-04 21:28:42 +0000
commite8d62395de6c1b3844294c5b6c09428c315ac42a (patch)
treef94a43e157b5b4607f3a8d5b9b7be873d458fafa /kdirstat/kcleanupcollection.cpp
parent1ed26cd2c4d896ae560dc7dddb570fe14ef573f3 (diff)
downloadkdirstat-e8d62395de6c1b3844294c5b6c09428c315ac42a.tar.gz
kdirstat-e8d62395de6c1b3844294c5b6c09428c315ac42a.zip
TQt4 port kdirstat
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kdirstat@1239296 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdirstat/kcleanupcollection.cpp')
-rw-r--r--kdirstat/kcleanupcollection.cpp40
1 files changed, 20 insertions, 20 deletions
diff --git a/kdirstat/kcleanupcollection.cpp b/kdirstat/kcleanupcollection.cpp
index fffa9b4..8b10505 100644
--- a/kdirstat/kcleanupcollection.cpp
+++ b/kdirstat/kcleanupcollection.cpp
@@ -18,14 +18,14 @@ using namespace KDirStat;
KCleanupCollection::KCleanupCollection( KActionCollection * actionCollection )
- : QObject()
+ : TQObject()
, _actionCollection( actionCollection )
{
/**
* All cleanups beloningt to this collection are stored in two separate Qt
* collections, a QList and a QDict. Make _one_ of them manage the cleanup
* objects, i.e. have them clear the KCleanup objects upon deleting. The
- * QList is the master collection, the QDict the slave.
+ * TQList is the master collection, the TQDict the slave.
**/
_cleanupList.setAutoDelete( true );
@@ -36,7 +36,7 @@ KCleanupCollection::KCleanupCollection( KActionCollection * actionCollection )
KCleanupCollection::KCleanupCollection( const KCleanupCollection &src )
- : QObject()
+ : TQObject()
{
deepCopy( src );
@@ -80,7 +80,7 @@ KCleanupCollection::operator= ( const KCleanupCollection &src )
* limitations of the KCleanup copy constructor: It doesn't make a
* truly identical copy of the entire KCleanup object. Rather, it
* copies only the KCleanup members and leaves most of the KAction
- * members (the parent class) untouched.
+ * members (the tqparent class) untouched.
*
* The behaviour implemented here comes handy in the most common
* situation where this assignment operator is used:
@@ -190,17 +190,17 @@ KCleanupCollection::add( KCleanup *newCleanup )
_cleanupList.append( newCleanup );
_cleanupDict.insert( newCleanup->id(), newCleanup );
- connect( this, SIGNAL( selectionChanged( KFileInfo * ) ),
- newCleanup, SLOT ( selectionChanged( KFileInfo * ) ) );
+ connect( this, TQT_SIGNAL( selectionChanged( KFileInfo * ) ),
+ newCleanup, TQT_SLOT ( selectionChanged( KFileInfo * ) ) );
- connect( this, SIGNAL( readConfig() ),
- newCleanup, SLOT ( readConfig() ) );
+ connect( this, TQT_SIGNAL( readConfig() ),
+ newCleanup, TQT_SLOT ( readConfig() ) );
- connect( this, SIGNAL( saveConfig() ),
- newCleanup, SLOT ( saveConfig() ) );
+ connect( this, TQT_SIGNAL( saveConfig() ),
+ newCleanup, TQT_SLOT ( saveConfig() ) );
- connect( newCleanup, SIGNAL( executed() ),
- this, SLOT ( cleanupExecuted() ) );
+ connect( newCleanup, TQT_SIGNAL( executed() ),
+ this, TQT_SLOT ( cleanupExecuted() ) );
}
@@ -222,16 +222,16 @@ KCleanupCollection::addUserCleanups( int number )
{
for ( int i=0; i < number; i++ )
{
- QString id;
+ TQString id;
id.sprintf( "cleanup_user_defined_%d", _nextUserCleanupNo );
- QString title;
+ TQString title;
if ( _nextUserCleanupNo <= 9 )
// Provide a keyboard shortcut for cleanup #0..#9
- title=i18n( "User Defined Cleanup #&%1" ).arg(_nextUserCleanupNo);
+ title=i18n( "User Defined Cleanup #&%1" ).tqarg(_nextUserCleanupNo);
else
// No keyboard shortcuts for cleanups #10.. - they would be duplicates
- title=i18n( "User Defined Cleanup #%1" ).arg(_nextUserCleanupNo);
+ title=i18n( "User Defined Cleanup #%1" ).tqarg(_nextUserCleanupNo);
_nextUserCleanupNo++;
@@ -242,7 +242,7 @@ KCleanupCollection::addUserCleanups( int number )
if ( i <= 9 )
{
// Provide an application-wide keyboard accelerator for cleanup #0..#9
- cleanup->setShortcut( Qt::CTRL + Qt::Key_0 + i );
+ cleanup->setShortcut( TQt::CTRL + TQt::Key_0 + i );
}
add( cleanup );
@@ -251,7 +251,7 @@ KCleanupCollection::addUserCleanups( int number )
KCleanup *
-KCleanupCollection::cleanup( const QString & id )
+KCleanupCollection::cleanup( const TQString & id )
{
return _cleanupDict[ id ];
}
@@ -18,14 +18,14 @@ using namespace KDirStat;
{
/**
- * All cleanups beloningt to this collection are stored in two separate Qt
- * collections, a QList and a QDict. Make _one_ of them manage the cleanup
+ * All cleanups beloningt to this collection are stored in two separate TQt
+ * collections, a TQList and a TQDict. Make _one_ of them manage the cleanup
* objects, i.e. have them clear the KCleanup objects upon deleting. The